changeset 5de33b3f0b76 in modules/account:default
details: https://hg.tryton.org/modules/account?cmd=changeset&node=5de33b3f0b76
description:
        Lock move table when closing period

        issue11093
        review395221002
diffstat:

 period.py |  3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)

diffs (14 lines):

diff -r 5a15561b28ce -r 5de33b3f0b76 period.py
--- a/period.py Tue Dec 21 23:28:05 2021 +0100
+++ b/period.py Tue Jan 04 22:17:13 2022 +0100
@@ -302,8 +302,9 @@
         Account = pool.get('account.account')
         transaction = Transaction()
 
         # Lock period to be sure no new period will be created in between.
         JournalPeriod.lock()
+        Move.lock()
 
         for period in periods:
             with transaction.set_context(
@@ -302,8 +302,9 @@
         transaction = Transaction()
 
-        # Lock period to be sure no new period will be created in between.
+        # Lock period and move to be sure no new record will be created
         JournalPeriod.lock()

Reply via email to